
// $Id: taskbar.cpp,v 1.31 2010/04/14 16:12:28 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    Taskbar.cc
\brief   main file
\author  Hugo Pereira
\version $Revision: 1.31 $
\date    $Date: 2010/04/14 16:12:28 $
*/

#include <signal.h>

#include <QApplication>

#include "Application.h"
#include "DefaultOptions.h"
#include "ErrorHandler.h"
#include "File.h"
#include "Singleton.h"
#include "SvgEngine.h"
#include "Util.h"

#include "CompositeEngine.h"

using namespace std;

//_______________________________
//! to handle keyboard interuptions
void Interupt_CB( int sig );

//__________________________________________
int main (int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  Interupt_CB);
    signal(SIGTERM, Interupt_CB);

    // install error handler
    qInstallMsgHandler( ErrorHandler::Throw );

    // load possible command file (supposibly last argument, not starting with a "-"=
    CommandLineArguments arguments( argc, argv );
    CommandLineParser parser( SERVER::ApplicationManager::commandLineParser( arguments, false ) );
    if( parser.hasFlag( "--help" ) )
    {
        Application::usage();
        return 0;
    }

    // default options
    installDefaultOptions();

    // these are needed to set default values to relevant options
    SVG::SvgEngine::get();
    TRANSPARENCY::CompositeEngine::get();

    // customize options
    XmlOptions::read( XmlOptions::get().raw( "RC_FILE" ) );
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) XmlOptions::get().print();

    // db file
    /* try load the file from command line, and default file if it fails */
    QStringList filenames( parser.orphans() );
    if( !filenames.isEmpty() ) XmlOptions::get().setRaw( "XML_FILE", filenames.front() );

    // initialize main frame and run loop
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( baseSvg );

    // create Application
    QApplication* application( 0 );
    TRANSPARENCY::CompositeEngine::get().initialize();
    #ifdef Q_WS_X11
    if( TRANSPARENCY::CompositeEngine::get().isAvailable() )
    {
        application = new QApplication(
            TRANSPARENCY::CompositeEngine::get().display(),
            argc, argv,
            TRANSPARENCY::CompositeEngine::get().visual(),
            TRANSPARENCY::CompositeEngine::get().colormap() );
    } else application = new QApplication( argc, argv );
    #else
    application = new QApplication( argc, argv );
    #endif

    application->setApplicationName( "transparent-taskbar" );

    Application singleton( arguments );
    Singleton::get().setApplication( &singleton );
    singleton.initApplicationManager();

    application->exec();
    delete application;

    return 0;

}


//_____________________________________________
void Interupt_CB( int sig )
{
    Debug::Throw() << "Interupt_CB - Recieved signal " << sig << endl;
    qApp->quit();
}
